@@ -481,11 +481,11 @@ class CfnFilter(
         def __init__(
             self,
             *,
-            eq: typing.Optional[typing.List[builtins.str]] = None,
+            eq: typing.Optional[typing.Sequence[builtins.str]] = None,
             gte: typing.Optional[jsii.Number] = None,
             lt: typing.Optional[jsii.Number] = None,
             lte: typing.Optional[jsii.Number] = None,
-            neq: typing.Optional[typing.List[builtins.str]] = None,
+            neq: typing.Optional[typing.Sequence[builtins.str]] = None,
         ) -> None:
             '''
             :param eq: ``CfnFilter.ConditionProperty.Eq``.
